Package: psychotree
Title: Recursive Partitioning Based on Psychometric Models
Version: 0.16-2
Date: 2025-07-25
Authors@R: c(person(given = "Achim", family = "Zeileis", role = c("aut", "cre"), email = "Achim.Zeileis@R-project.org", comment = c(ORCID = "0000-0003-0918-3766")),
             person(given = "Carolin", family = "Strobl", role = "aut", email = "Carolin.Strobl@psychologie.uzh.ch", comment = c(ORCID = "0000-0003-0952-3230")),
             person(given = "Florian", family = "Wickelmaier", role = "aut"),
             person(given = "Basil", family = "Komboz", role = "aut"),
             person(given = "Julia", family = "Kopf", role = "aut"),
             person(given = "Lennart", family = "Schneider", role = "aut", email = "Lennart.Sch@web.de", comment = c(ORCID = "0000-0003-4152-5308")),
             person(given = "David", family = "Dreifuss", role = "aut"), 
             person(given = "Rudolf", family = "Debelak", role = "aut", email = "rudolf.debelak@gmail.com", comment = c(ORCID = "0000-0001-8900-2106")))
Depends: R (>= 4.0.0), partykit (>= 1.2-9), psychotools (>= 0.7-1)
Suggests: stablelearner (>= 0.1-3), strucchange, tinytest, mirt
Imports: graphics, grDevices, grid, stats, Formula
Description: Recursive partitioning based on psychometric models,
  employing the general MOB algorithm (from package partykit) to obtain
  Bradley-Terry trees, Rasch trees, rating scale and partial credit trees, and
  MPT trees, trees for 1PL, 2PL, 3PL and 4PL models and generalized partial 
  credit models.
License: GPL-2 | GPL-3
NeedsCompilation: no
Packaged: 2025-07-25 01:57:28 UTC; zeileis
Author: Achim Zeileis [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0918-3766>),
  Carolin Strobl [aut] (ORCID: <https://orcid.org/0000-0003-0952-3230>),
  Florian Wickelmaier [aut],
  Basil Komboz [aut],
  Julia Kopf [aut],
  Lennart Schneider [aut] (ORCID:
    <https://orcid.org/0000-0003-4152-5308>),
  David Dreifuss [aut],
  Rudolf Debelak [aut] (ORCID: <https://orcid.org/0000-0001-8900-2106>)
Maintainer: Achim Zeileis <Achim.Zeileis@R-project.org>
Repository: CRAN
Date/Publication: 2025-07-25 05:00:17 UTC
Built: R 4.6.0; ; 2026-04-27 16:48:10 UTC; unix
